# -*- coding: utf-8 -*-
"""
Bemessungswerte Holz
Dipl.-Ing. (FH) Heiko Lüttich
Stand: 2022-07-25
"""
### Standartbemessung für den Holzbau
import math

###Funktionen
##Spannungsnachweise

#Beiwert für die Höhe k,h
#k,k für Vollholz
def kh_WertVH(H, ROH):
    if ROH <= 700 and H < 15:
        kh_VH = (150/( H*10))**0.2
        if kh_VH >= 1.3:
            kh_VH = 1.3
        else:
            kh_VH = kh_VH
    else:
        kh_VH = 1.0
    return kh_VH

#k,k für BSH
def kh_WertBSH(H):
    if H < 60:
        kh_BSH = (600/( H*10))**0.1
        if kh_BSH >= 1.1:
            kh_BSH = 1.1
        else:
            kh_BSH = kh_BSH
    else:
        kh_BSH = 1.0
    return kh_BSH

#Bemessungswert Druckspannung Sigma, C,d
def druck_N(F, A):
    sigma_Cd = (F*1000)/(A*100)
    return sigma_Cd

#Bemessungswert Zugspannung Sigma,t,0,d
def zug_N(F, A):
    sigma_T0d = (F*1000)/(A*100)
    return sigma_T0d

#Bemessungswert der Biegespannung Sigma,M,y(z),d
def bieg_M(M, W):
    sigma_Md = M*0.001/(W*0.000001)
    return sigma_Md

#Nachweis Druck in Faserrichtung
def druck_ND(Sigma_Cd, Fc0d):
    eta = Sigma_Cd / Fc0d
    return eta

#Nachweis einachsige Biegung mit Druck
def ein_BiegDruck(SigmaC0d, Fc0d, SigmaM, Fmd, KH_Bieg):
    eta = ((SigmaC0d/Fc0d)**2 + (SigmaM/(Fmd * KH_Bieg)))
    return eta

#Nachweis zweiachsige Biegung mit Druck
def zwei_BiegDruck(SigmaC0d, Fc0d, SigmaMyd, Fmyd, SigmaMzd, Fmzd, Km, KH_Bieg):
    eta_Liste = []
    eta_y = ((SigmaC0d/Fc0d)**2 + (SigmaMyd/(Fmyd * KH_Bieg)) + Km*(SigmaMzd/Fmzd))
    eta_Liste.append(eta_y)
    eta_z = ((SigmaC0d/Fc0d)**2 + Km*(SigmaMyd/(Fmyd * KH_Bieg)) + (SigmaMzd/Fmzd))
    eta_Liste.append(eta_z)
    return eta_Liste           

#Nachweis Zug in Faserrichtung
def zug_ND(Sigma_Cd, Ft0d, KH_Zug):
    eta = Sigma_Cd / (Ft0d * KH_Zug)
    return eta

#Nachweis einachsige Biegung mit Zug
def ein_BiegZug(SigmaC0d, Ft0d, SigmaM, Fmd, KH_Zug, KH_Bieg):
    eta = ((SigmaC0d/(Ft0d * KH_Zug)) + (SigmaM/(Fmd * KH_Bieg)))
    return eta

#Nachweis zweiachsige Biegung mit Zug
def zwei_BiegZug(SigmaC0d, Ft0d, SigmaMyd, Fmyd, SigmaMzd, Fmzd, Km, KH_Zug, KH_Bieg):
    eta_Liste = []
    eta_y = ((SigmaC0d/(Ft0d * KH_Zug)) + (SigmaMyd/(Fmyd * KH_Bieg)) + Km*(SigmaMzd/Fmzd))
    eta_Liste.append(eta_y)
    eta_z = ((SigmaC0d/Ft0d) + Km*(SigmaMyd/(Fmyd * KH_Bieg)) + (SigmaMzd/Fmzd))
    eta_Liste.append(eta_z)
    return eta_Liste

#Schubnachweise
#Berücksichtigung von Rissen kcr beim Schub
#bei Schub in Y-Richtung B und H vertauschen
def a_Eff(B, H, Kcr):
    A_eff = Kcr * B * H
    return A_eff

#Bemessungswert Schubspannug
def schub_V(V, Aeff):
    tau_Vd = (3 * V*1000) / (2 * Aeff*100)
    return tau_Vd

#Nachweis Schubspannung einachsig
def tau_SchubEins(TAU_Vd, FVd):
    eta = TAU_Vd / FVd
    return eta

#Nachweis Schubspannung zweiachsig
def tau_SchubZwei(TauYd, TauZd, FVd):
    eta = ((TauYd / FVd)**2) + ((TauZd / FVd)**2)
    return eta


### Beiwerte + Nachweis Biegeknicken ###
#Ersatzstablänge
def l_ef(beta, L):
    L_ef = beta * L
    return L_ef

#Schlankheitsgrad
def lamda(l_ef, i_rad):
    lamda_schlank = l_ef * 100 / i_rad
    return lamda_schlank

#bezogener Schlankheitsgrad
def lambda_Rel(lamda, Fc0k, E005):
    Lamda_Rel = (lamda/math.pi) * (Fc0k / E005)**0.5
    return Lamda_Rel

#Formelbeiwert k
def k_Formel(BETA_C, LAMDA_REL):
    k_Form = 0.5 * (1 + BETA_C * (LAMDA_REL - 0.3) + LAMDA_REL**2)
    return k_Form

#Knickbeiwert kc,(y,z)
def kc_Knick(K_FORM, LAMPDA_REL):
    KC_Knick = 1 / (K_FORM + (K_FORM**2 - LAMPDA_REL**2)**0.5)
    if KC_Knick < 1.0:
        KC_Knick = KC_Knick
    else:
        KC_Knick = 1.0
    return KC_Knick

#Nachweis Biegeknicken (BK) nur mit Druck
def bk_N(sigma_Cd, Fc0d, KC_KNICK_Y, KC_KNICK_Z):
    eta_Liste = []
    eta_y = sigma_Cd / (KC_KNICK_Y * Fc0d)
    eta_Liste.append(eta_y)
    eta_z = sigma_Cd / (KC_KNICK_Z * Fc0d)
    eta_Liste.append(eta_z)
    return eta_Liste

#Nachweis Biegeknicken (BK), zweiachsig  
def biege_Knick(SigmaC0d, Fc0d, KC_KnickY, KC_KnickZ, SigmaMyd, Fmyd, SigmaMzd, Fmzd, Km, KH_Bieg):
    eta_Liste = []
    eta_y = (SigmaC0d / (KC_KnickY * Fc0d)) + (SigmaMyd / (Fmyd * KH_Bieg)) + (Km *(SigmaMzd / Fmzd))
    eta_Liste.append(eta_y)
    eta_z = (SigmaC0d / (KC_KnickZ * Fc0d)) + (Km * (SigmaMyd / (Fmyd * KH_Bieg)) + (SigmaMzd / Fmzd))
    eta_Liste.append(eta_z)
    return eta_Liste

#Vergleich der Ausnutzung
def vergleich(ETA):
    if ETA <= 1.0:
        print("NW erbracht!")
        print("press EXE")
        input("")
    else:
        print("NW NICHT erbracht!")
        print("press EXE")
        input("")